clear; clc; clf;

%% pre GEM info

% parameters and replicates
    r = 0.5;
    K = 50;
    num_replicates = 20;

% evolution and solution details
    h_2 = 1; % narrow-sense heritability
    cv = 0.3; % coefficient of variation of trait
    y0 = 5; % starting population size
    t_max = 30; % time span to run simulations    
    tspan = [0 t_max]; % start and end times
    
%% set up and run GEM 

[stand_times, R_data_out, x_data_out, x_var_data_out] = GEMv2_logistic_growth(r, K, cv, h_2, num_replicates, y0, t_max);

%% Solve non-evolutionary ODE for realized initial conditions
realized_initial_r = x_data_out(1,1); % get the average of the realized starting epsilons
realized_initial_r_var = x_var_data_out(1,1);

ode = @(t,y) LG_model(t,y,realized_initial_r,K); % compile function and call
    [t1,y1] = ode45(ode, tspan, y0); % return time and population density vectors

%% plotting
figure(1); % plot medians and ci's overtop individual lines
    subplot(3,1,1); box on;
        jbfill(stand_times,R_data_out(2,:),R_data_out(3,:),[0.5 0.5 0.5],'w',1,0.2); 
        hold on;
        plot(stand_times,R_data_out(1,:),'-','Color','b','LineWidth',2);
        plot([0 t_max],[K K],'--k');
        plot(t1,y1(:,1),'-k','LineWidth',2);
        xlim([0 t_max]);
        ylabel('Population size','FontSize',12);
    subplot(3,1,2); box on;
        jbfill(stand_times,x_data_out(2,:),x_data_out(3,:),[0.5 0.5 0.5],'w',1,0.2); 
        hold on;
        plot(stand_times,x_data_out(1,:),'-','Color','b','LineWidth',2);
        plot([0 t_max],[realized_initial_r realized_initial_r],'--k');
        xlim([0 t_max]);
        ylabel('Mean birth rate','FontSize',12);
    subplot(3,1,3); box on;
        jbfill(stand_times,x_var_data_out(2,:),x_var_data_out(3,:),[0.5 0.5 0.5],'w',1,0.2); 
        hold on;
        plot(stand_times,x_var_data_out(1,:),'-','Color','b','LineWidth',2);
        plot([0 t_max],[realized_initial_r_var realized_initial_r_var],'--k');
        xlim([0 t_max]);
        ylabel('Variance in birth rate','FontSize',12);
        xlabel('Time','FontSize',12);
